@@ -207,7 +207,7 @@ class Test_grouping(unittest.TestCase):
         uvp = ds.pspec(baselines1, baselines2, dsets=(0, 1), pols=[('xx', 'xx')], 
                        spw_ranges=(175,195), taper='bh',verbose=False)
         # get exact window functions
-        uvp.get_exact_window_functions(ftbeam_file = os.path.join(DATA_PATH, 'FT_beam_HERA_dipole_test'),
+        uvp.get_exact_window_functions(ftbeam=os.path.join(DATA_PATH, 'FT_beam_HERA_dipole_test'),
                                        spw_array=None, inplace=True, verbose=False)
 
         # time average
@@ -607,7 +607,7 @@ def test_spherical_average():
     uvp = ds.pspec(baselines1, baselines2, dsets=(0, 1), pols=[('xx', 'xx')], 
                    spw_ranges=(175,195), taper='bh',verbose=False)
     # get exact window functions
-    uvp.get_exact_window_functions(ftbeam_file = os.path.join(DATA_PATH, 'FT_beam_HERA_dipole_test'),
+    uvp.get_exact_window_functions(ftbeam=os.path.join(DATA_PATH, 'FT_beam_HERA_dipole_test'),
                                    spw_array=None, inplace=True, verbose=False)
     # spherical window functions for redundant groups
     sph = grouping.spherical_average(uvp, kbins, bin_widths)
@@ -640,7 +640,7 @@ def test_spherical_wf_from_uvp():
     uvp.cosmo = conversions.Cosmo_Conversions() #uvp.set_cosmology not overwriting
 
     # obtain exact_windows (fiducial usage)
-    uvp.get_exact_window_functions(ftbeam_file = os.path.join(DATA_PATH, basename),
+    uvp.get_exact_window_functions(ftbeam=os.path.join(DATA_PATH, basename),
                                    inplace=True)
     wf_array = grouping.spherical_wf_from_uvp(uvp,
                                               kbins=np.arange(0.1, 2.9, dk),
